@@ -7,13 +7,13 @@ from scipy.constants import Planck, electron_mass, elementary_charge, speed_of_l
 
 def lorentz(keV):
     """
-    Relativistic factor :math:`\gamma`, defined as :math:`\gamma = \\frac{1}{\sqrt{1 - v^2/c^2}}`
+    Relativistic factor :math:`\\gamma`, defined as :math:`\\gamma = \\frac{1}{\\sqrt{1 - v^2/c^2}}`
 
     Parameters
     ----------
     keV : array_like or float
         Electron energy [keV].
-    
+
     Returns
     -------
     out : array_like or float
@@ -26,20 +26,20 @@ def lorentz(keV):
 
 
 def electron_wavelength(keV):
-    """ 
-    Relativistic wavelength :math:`\lambda` of an accelerated electron.
+    """
+    Relativistic wavelength :math:`\\lambda` of an accelerated electron.
 
     .. math::
 
-        \lambda = \\frac{h}{\sqrt{2 m_e e V}}\gamma
-    
-    where :math:`\gamma` is the relativistic Lorentz factor.
-        
+        \\lambda = \\frac{h}{\\sqrt{2 m_e e V}}\\gamma
+
+    where :math:`\\gamma` is the relativistic Lorentz factor.
+
     Parameters
     ----------
     keV : array_like or float
         Electron energy [keV].
-    
+
     Returns
     -------
     out : array_like or float
@@ -64,13 +64,13 @@ def electron_velocity(keV):
 
     .. math::
 
-        \\frac{v_e}{c} = \sqrt{1 - \\frac{m_0 c^2}{m_0 c^2 + e V}}
+        \\frac{v_e}{c} = \\sqrt{1 - \\frac{m_0 c^2}{m_0 c^2 + e V}}
 
     Parameters
     ----------
     keV : array_like or float
         Electron energy [keV].
-    
+
     Returns
     -------
     out : array_like or float
@@ -94,7 +94,7 @@ def interaction_parameter(keV):
     ----------
     keV : array_like or float
         Electron energy [keV].
-    
+
     Returns
     -------
     out : array_like or float
