@@ -5,12 +5,15 @@ Kinematic simulation of diffraction patterns
 """
 
 import numpy as np
-from scipy.fftpack import next_fast_len
+from os import cpu_count
+import scipy.fft as fft
+from ..fft import with_skued_fft
 from .potential import pelectrostatic
 from ..eproperties import interaction_parameter
 from scipy.interpolate import RegularGridInterpolator
 
 
+@with_skued_fft
 def kinematicsim(crystal, kx, ky, energy=90):
     """
     Propagate a plane wave through a crystal and compute the resulting
@@ -20,7 +23,7 @@ def kinematicsim(crystal, kx, ky, energy=90):
 
     Parameters
     ----------
-    crystal : skued.Crystal
+    crystal : crystals.Crystal
         Crystal from which to scatter.
     kx, ky :  `~numpy.ndarray`, shape (N,M)
         Momenta mesh where to calculate the diffraction pattern [:math:`Å^{-1}`]
@@ -32,7 +35,7 @@ def kinematicsim(crystal, kx, ky, energy=90):
     diff_pattern : `~numpy.ndarray`
         Scattered intensity.
     """
-    shape = tuple(map(next_fast_len, kx.shape))
+    shape = tuple(map(fft.next_fast_len, kx.shape))
     period_x, period_y, period_z = crystal.periodicity
 
     # We create the grid ourselves so that we minimize Fourier artifacts as much as possible.
@@ -52,13 +55,13 @@ def kinematicsim(crystal, kx, ky, energy=90):
     potential = pelectrostatic(crystal, xx, yy)
     transmission_function = np.exp(1j * interaction_parameter(energy) * potential)
 
-    exit_wave = np.fft.ifft2(
-        np.fft.fft2(np.ones_like(xx, dtype=np.complex) * transmission_function)
+    exit_wave = fft.ifft2(
+        fft.fft2(np.ones_like(xx, dtype=np.complex) * transmission_function)
     )
-    intensity = np.fft.fftshift(np.abs(np.fft.fft2(exit_wave)) ** 2)
+    intensity = fft.fftshift(np.abs(fft.fft2(exit_wave)) ** 2)
 
-    kx_ = np.fft.fftshift(kx_)
-    ky_ = np.fft.fftshift(ky_)
+    kx_ = fft.fftshift(kx_)
+    ky_ = fft.fftshift(ky_)
 
     # Note that the definition of 'frequency' in fftfreq & friends necessitates dividing by 2pi
     twopi = 2 * np.pi
@@ -103,8 +106,8 @@ def fft2freq(x, y, indexing="xy"):
     spacing_x = abs(extent_x[1] - extent_x[0])
     spacing_y = abs(extent_y[1] - extent_y[0])
 
-    freqs_x = np.fft.fftfreq(len(extent_x), d=spacing_x)
-    freqs_y = np.fft.fftfreq(len(extent_y), d=spacing_y)
+    freqs_x = fft.fftfreq(len(extent_x), d=spacing_x)
+    freqs_y = fft.fftfreq(len(extent_y), d=spacing_y)
 
     return np.meshgrid(freqs_x, freqs_y, indexing=indexing)
 
@@ -127,6 +130,6 @@ def limit_bandwidth(image, K, limit):
     limited : `~numpy.ndarray`
         Bandwidth-limited image.
     """
-    image_fft = np.fft.fft2(image)
+    image_fft = fft.fft2(image)
     image_fft[K > limit] = 0.0
-    return np.fft.ifft2(image_fft)
+    return fft.ifft2(image_fft)
